@@ -28,9 +28,16 @@ class Parser(object):
                 pass
         return default
 
-    def html(self):
+    def html(self, unicode=False):
         """ Return html of element """
-        return lxml.html.tostring(self.element, encoding=self.encoding)
+        html = lxml.html.tostring(self.element, encoding=self.encoding)
+        if unicode:
+            html = html.decode(self.encoding)
+        return html
+
+    def inner_html(self):
+        return getattr(self, 'text', '') + ''.join(
+                child.html(unicode=True) for child in self.iterchildren())
 
     def __unicode__(self):
         return lxml.html.tostring(self.element, method='text', encoding=self.encoding).decode(self.encoding)
@@ -77,7 +84,7 @@ class Parser(object):
             return self._wrap_result(result)
         else:
             return result
-    
+
     def __setattr__(self, name, value):
         """ Easy access to attribute modification """
         # Simple hack for break setattr recursion
@@ -85,14 +92,14 @@ class Parser(object):
             super(Parser, self).__setattr__(name, value)
         if name in self.element.attrib:
             self.element.attrib[name] = value
-    
+
     def __nonzero__(self):
         return self.element is not None
 
 
-def parse(html_string, wrapper=Parser):
+def parse(html_string, wrapper=Parser, *args, **kwargs):
     """ Parse html with wrapper """
-    return Parser(lxml.html.fromstring(html_string))
+    return Parser(lxml.html.fromstring(html_string), *args, **kwargs)
 
 
 def str2int(string_with_int):
